==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VpnGatewayNatRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.VpnNatRuleMode
import com.pulumi.azurenative.network.kotlin.enums.VpnNatRuleType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * VpnGatewayNatRule Resource.
 * @property externalMappings The private IP address external mapping for NAT.
 * @property id Resource ID.
 * @property internalMappings The private IP address internal mapping for NAT.
 * @property ipConfigurationId The IP Configuration ID this NAT rule applies to.
 * @property mode The Source NAT direction of a VPN NAT.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property type The type of NAT rule for VPN NAT.
 */
public data class VpnGatewayNatRuleArgs(
    public val externalMappings: Output<List<VpnNatRuleMappingArgs>>? = null,
    public val id: Output<String>? = null,
    public val internalMappings: Output<List<VpnNatRuleMappingArgs>>? = null,
    public val ipConfigurationId: Output<String>? = null,
    public val mode: Output<Either<String, VpnNatRuleMode>>? = null,
    public val name: Output<String>? = null,
    public val type: Output<Either<String, VpnNatRuleType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs =
        com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs.builder()
            .externalMappings(
                externalMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .id(id?.applyValue({ args0 -> args0 }))
            .internalMappings(
                internalMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ipConfigurationId(ipConfigurationId?.applyValue({ args0 -> args0 }))
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VpnGatewayNatRuleArgs].
 */
@PulumiTagMarker
public class VpnGatewayNatRuleArgsBuilder internal constructor() {
    private var externalMappings: Output<List<VpnNatRuleMappingArgs>>? = null

    private var id: Output<String>? = null

    private var internalMappings: Output<List<VpnNatRuleMappingArgs>>? = null

    private var ipConfigurationId: Output<String>? = null

    private var mode: Output<Either<String, VpnNatRuleMode>>? = null

    private var name: Output<String>? = null

    private var type: Output<Either<String, VpnNatRuleType>>? = null

    /**
     * @param value The private IP address external mapping for NAT.
     */
    @JvmName("oysbtsloavtonqar")
    public suspend fun externalMappings(`value`: Output<List<VpnNatRuleMappingArgs>>) {
        this.externalMappings = value
    }

    @JvmName("xhuqdenaupumfxqq")
    public suspend fun externalMappings(vararg values: Output<VpnNatRuleMappingArgs>) {
        this.externalMappings = Output.all(values.asList())
    }

    /**
     * @param values The private IP address external mapping for NAT.
     */
    @JvmName("bykuirllfmtjivxd")
    public suspend fun externalMappings(values: List<Output<VpnNatRuleMappingArgs>>) {
        this.externalMappings = Output.all(values)
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("bxlatejmdmycnihw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The private IP address internal mapping for NAT.
     */
    @JvmName("jqkyonrdxuhhloyo")
    public suspend fun internalMappings(`value`: Output<List<VpnNatRuleMappingArgs>>) {
        this.internalMappings = value
    }

    @JvmName("ukgmfvymqafdwlis")
    public suspend fun internalMappings(vararg values: Output<VpnNatRuleMappingArgs>) {
        this.internalMappings = Output.all(values.asList())
    }

    /**
     * @param values The private IP address internal mapping for NAT.
     */
    @JvmName("labklapxadtaafkg")
    public suspend fun internalMappings(values: List<Output<VpnNatRuleMappingArgs>>) {
        this.internalMappings = Output.all(values)
    }

    /**
     * @param value The IP Configuration ID this NAT rule applies to.
     */
    @JvmName("hkmswswwcxvqjlya")
    public suspend fun ipConfigurationId(`value`: Output<String>) {
        this.ipConfigurationId = value
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("evrigdgubhxqrprw")
    public suspend fun mode(`value`: Output<Either<String, VpnNatRuleMode>>) {
        this.mode = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("tbaqksvetnwgjfet")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("kwcqokjuyhfoieyy")
    public suspend fun type(`value`: Output<Either<String, VpnNatRuleType>>) {
        this.type = value
    }

    /**
     * @param value The private IP address external mapping for NAT.
     */
    @JvmName("tqtsqbgniijvvtdv")
    public suspend fun externalMappings(`value`: List<VpnNatRuleMappingArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalMappings = mapped
    }

    /**
     * @param argument The private IP address external mapping for NAT.
     */
    @JvmName("sxfnkueljgpnxeds")
    public suspend
    fun externalMappings(argument: List<suspend VpnNatRuleMappingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.externalMappings = mapped
    }

    /**
     * @param argument The private IP address external mapping for NAT.
     */
    @JvmName("efrqltpecuggprcu")
    public suspend fun externalMappings(
        vararg
        argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.externalMappings = mapped
    }

    /**
     * @param argument The private IP address external mapping for NAT.
     */
    @JvmName("bqpmhxqrlghnakhh")
    public suspend fun externalMappings(argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VpnNatRuleMappingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.externalMappings = mapped
    }

    /**
     * @param values The private IP address external mapping for NAT.
     */
    @JvmName("fisvuhgtkfdjkijt")
    public suspend fun externalMappings(vararg values: VpnNatRuleMappingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.externalMappings = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("ayvahwvelhaaugns")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The private IP address internal mapping for NAT.
     */
    @JvmName("adcfcquaqoptkcbm")
    public suspend fun internalMappings(`value`: List<VpnNatRuleMappingArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.internalMappings = mapped
    }

    /**
     * @param argument The private IP address internal mapping for NAT.
     */
    @JvmName("llpjcxbusjrsqmkq")
    public suspend
    fun internalMappings(argument: List<suspend VpnNatRuleMappingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.internalMappings = mapped
    }

    /**
     * @param argument The private IP address internal mapping for NAT.
     */
    @JvmName("xkalpjuykqurdsik")
    public suspend fun internalMappings(
        vararg
        argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.internalMappings = mapped
    }

    /**
     * @param argument The private IP address internal mapping for NAT.
     */
    @JvmName("abcnniaexmreawpi")
    public suspend fun internalMappings(argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VpnNatRuleMappingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.internalMappings = mapped
    }

    /**
     * @param values The private IP address internal mapping for NAT.
     */
    @JvmName("tgclayhubqksncjs")
    public suspend fun internalMappings(vararg values: VpnNatRuleMappingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.internalMappings = mapped
    }

    /**
     * @param value The IP Configuration ID this NAT rule applies to.
     */
    @JvmName("jdsnmdtojvnlqpxo")
    public suspend fun ipConfigurationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipConfigurationId = mapped
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("rfokioencsjwxova")
    public suspend fun mode(`value`: Either<String, VpnNatRuleMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("adoxnpbfdwiicufm")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VpnNatRuleMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("uolnsnonqexikmed")
    public fun mode(`value`: VpnNatRuleMode) {
        val toBeMapped = Either.ofRight<String, VpnNatRuleMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("esuaeybbrykymrov")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("gmxpifldhalqdgxa")
    public suspend fun type(`value`: Either<String, VpnNatRuleType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("ddaiuxblfwydngcr")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VpnNatRuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("wgpftahmpcyuoclk")
    public fun type(`value`: VpnNatRuleType) {
        val toBeMapped = Either.ofRight<String, VpnNatRuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): VpnGatewayNatRuleArgs = VpnGatewayNatRuleArgs(
        externalMappings = externalMappings,
        id = id,
        internalMappings = internalMappings,
        ipConfigurationId = ipConfigurationId,
        mode = mode,
        name = name,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VpnGatewayNatRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.VpnNatRuleMode
import com.pulumi.azurenative.network.kotlin.enums.VpnNatRuleType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * VpnGatewayNatRule Resource.
 * @property externalMappings The private IP address external mapping for NAT.
 * @property id Resource ID.
 * @property internalMappings The private IP address internal mapping for NAT.
 * @property ipConfigurationId The IP Configuration ID this NAT rule applies to.
 * @property mode The Source NAT direction of a VPN NAT.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property type The type of NAT rule for VPN NAT.
 */
public data class VpnGatewayNatRuleArgs(
    public val externalMappings: Output<List<VpnNatRuleMappingArgs>>? = null,
    public val id: Output<String>? = null,
    public val internalMappings: Output<List<VpnNatRuleMappingArgs>>? = null,
    public val ipConfigurationId: Output<String>? = null,
    public val mode: Output<Either<String, VpnNatRuleMode>>? = null,
    public val name: Output<String>? = null,
    public val type: Output<Either<String, VpnNatRuleType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs =
        com.pulumi.azurenative.network.inputs.VpnGatewayNatRuleArgs.builder()
            .externalMappings(
                externalMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .id(id?.applyValue({ args0 -> args0 }))
            .internalMappings(
                internalMappings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ipConfigurationId(ipConfigurationId?.applyValue({ args0 -> args0 }))
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VpnGatewayNatRuleArgs].
 */
@PulumiTagMarker
public class VpnGatewayNatRuleArgsBuilder internal constructor() {
    private var externalMappings: Output<List<VpnNatRuleMappingArgs>>? = null

    private var id: Output<String>? = null

    private var internalMappings: Output<List<VpnNatRuleMappingArgs>>? = null

    private var ipConfigurationId: Output<String>? = null

    private var mode: Output<Either<String, VpnNatRuleMode>>? = null

    private var name: Output<String>? = null

    private var type: Output<Either<String, VpnNatRuleType>>? = null

    /**
     * @param value The private IP address external mapping for NAT.
     */
    @JvmName("xbxmdursjbugkylo")
    public suspend fun externalMappings(`value`: Output<List<VpnNatRuleMappingArgs>>) {
        this.externalMappings = value
    }

    @JvmName("eltnculencyrfngx")
    public suspend fun externalMappings(vararg values: Output<VpnNatRuleMappingArgs>) {
        this.externalMappings = Output.all(values.asList())
    }

    /**
     * @param values The private IP address external mapping for NAT.
     */
    @JvmName("nmhucltxsjrhqfjb")
    public suspend fun externalMappings(values: List<Output<VpnNatRuleMappingArgs>>) {
        this.externalMappings = Output.all(values)
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("uagavdmhgqccbhuf")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The private IP address internal mapping for NAT.
     */
    @JvmName("euumeqwnadaetgsb")
    public suspend fun internalMappings(`value`: Output<List<VpnNatRuleMappingArgs>>) {
        this.internalMappings = value
    }

    @JvmName("ufjufnkrieohheoi")
    public suspend fun internalMappings(vararg values: Output<VpnNatRuleMappingArgs>) {
        this.internalMappings = Output.all(values.asList())
    }

    /**
     * @param values The private IP address internal mapping for NAT.
     */
    @JvmName("wtxyyjkhmgyqdgcs")
    public suspend fun internalMappings(values: List<Output<VpnNatRuleMappingArgs>>) {
        this.internalMappings = Output.all(values)
    }

    /**
     * @param value The IP Configuration ID this NAT rule applies to.
     */
    @JvmName("ichvtujamaudyjgj")
    public suspend fun ipConfigurationId(`value`: Output<String>) {
        this.ipConfigurationId = value
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("htbsduvftrvtffex")
    public suspend fun mode(`value`: Output<Either<String, VpnNatRuleMode>>) {
        this.mode = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("qvxydwhoaefpfnvq")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("cotnbpuyiplocnkf")
    public suspend fun type(`value`: Output<Either<String, VpnNatRuleType>>) {
        this.type = value
    }

    /**
     * @param value The private IP address external mapping for NAT.
     */
    @JvmName("ilpdvyrbcwtopsvm")
    public suspend fun externalMappings(`value`: List<VpnNatRuleMappingArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalMappings = mapped
    }

    /**
     * @param argument The private IP address external mapping for NAT.
     */
    @JvmName("vpbatymxfwlacwah")
    public suspend
    fun externalMappings(argument: List<suspend VpnNatRuleMappingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.externalMappings = mapped
    }

    /**
     * @param argument The private IP address external mapping for NAT.
     */
    @JvmName("acagccshrglmyvgn")
    public suspend fun externalMappings(
        vararg
        argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.externalMappings = mapped
    }

    /**
     * @param argument The private IP address external mapping for NAT.
     */
    @JvmName("gwqpixaecfakkskm")
    public suspend fun externalMappings(argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VpnNatRuleMappingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.externalMappings = mapped
    }

    /**
     * @param values The private IP address external mapping for NAT.
     */
    @JvmName("jycolwrcrsyymtan")
    public suspend fun externalMappings(vararg values: VpnNatRuleMappingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.externalMappings = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("xepjykplsqsglypf")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The private IP address internal mapping for NAT.
     */
    @JvmName("xxqvioswfjsnqlkk")
    public suspend fun internalMappings(`value`: List<VpnNatRuleMappingArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.internalMappings = mapped
    }

    /**
     * @param argument The private IP address internal mapping for NAT.
     */
    @JvmName("faokrcqlutdquelj")
    public suspend
    fun internalMappings(argument: List<suspend VpnNatRuleMappingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.internalMappings = mapped
    }

    /**
     * @param argument The private IP address internal mapping for NAT.
     */
    @JvmName("iisrecqkvswbiljv")
    public suspend fun internalMappings(
        vararg
        argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VpnNatRuleMappingArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.internalMappings = mapped
    }

    /**
     * @param argument The private IP address internal mapping for NAT.
     */
    @JvmName("gdfwaqcucehddcse")
    public suspend fun internalMappings(argument: suspend VpnNatRuleMappingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VpnNatRuleMappingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.internalMappings = mapped
    }

    /**
     * @param values The private IP address internal mapping for NAT.
     */
    @JvmName("qqpjobgsqdtiqigx")
    public suspend fun internalMappings(vararg values: VpnNatRuleMappingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.internalMappings = mapped
    }

    /**
     * @param value The IP Configuration ID this NAT rule applies to.
     */
    @JvmName("fuqikophkxwucula")
    public suspend fun ipConfigurationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipConfigurationId = mapped
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("merwafobyrtihuqg")
    public suspend fun mode(`value`: Either<String, VpnNatRuleMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("ejmjwvriagtymtai")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VpnNatRuleMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The Source NAT direction of a VPN NAT.
     */
    @JvmName("igxsgulqvshjaxmi")
    public fun mode(`value`: VpnNatRuleMode) {
        val toBeMapped = Either.ofRight<String, VpnNatRuleMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("fmnmsyhohhuwpicv")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("tyqtxjpljxhvwcig")
    public suspend fun type(`value`: Either<String, VpnNatRuleType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("ybuihqerofpasdof")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VpnNatRuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of NAT rule for VPN NAT.
     */
    @JvmName("jtapufnellgtnysy")
    public fun type(`value`: VpnNatRuleType) {
        val toBeMapped = Either.ofRight<String, VpnNatRuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): VpnGatewayNatRuleArgs = VpnGatewayNatRuleArgs(
        externalMappings = externalMappings,
        id = id,
        internalMappings = internalMappings,
        ipConfigurationId = ipConfigurationId,
        mode = mode,
        name = name,
        type = type,
    )
}
